@@ -50,3 +50,22 @@ class Message(object):
     @classmethod
     def url(cls):
         return '/messages'
+
+    @classmethod
+    def from_json(cls, obj):
+        if isinstance(obj, dict):
+            obj = cls(attributes=obj)
+        elif isinstance(obj, (str, unicode)):
+            obj = cls(attributes=json.loads(obj))
+        else:
+            raise TypeError('Data must be str or dict')
+        return obj
+
+    @classmethod
+    def get(cls, session, msgid=None):
+        url = '/messages/{}'.format(msgid)
+        resp = session.get(url)
+
+        obj = cls.from_json(resp.json())
+        return obj
+
